#!/bin/bash

# Uninstall Zoom on macOS
echo "Starting Zoom uninstallation..."

# Stop Zoom-related daemons
echo "Stopping Zoom daemons..."
sudo launchctl bootout system /Library/LaunchDaemons/us.zoom.ZoomDaemon.plist 2>/dev/null || echo "Zoom daemon already stopped or not found."

# Kill any Zoom processes
echo "Killing Zoom processes..."
sudo pkill -f "zoom" 2>/dev/null || echo "No Zoom processes running."

# Remove Zoom application and related files
echo "Removing Zoom application and related files..."
sudo rm -rf \
  "/Applications/zoom.us.app" \
  "/Users/$USER/Library/Application Support/ZoomUpdater" \
  "/Users/$USER/Library/WebKit/us.zoom.xos" \
  "/Users/$USER/Library/Preferences/ZoomChat.plist" \
  "/Users/$USER/Library/Application Scripts/BJ4HAAB9B3.ZoomClient3rd" \
  "/Users/$USER/Library/HTTPStorages/us.zoom.xos.binarycookies" \
  "/Users/$USER/Library/HTTPStorages/us.zoom.xos" \
  "/Users/$USER/Library/Logs/ZoomPhone" \
  "/Users/$USER/Library/Group Containers/BJ4HAAB9B3.ZoomClient3rd" \
  "/Library/PrivilegedHelperTools/us.zoom.ZoomDaemon" \
  "/Library/Logs/zoomusinstall.log" \
  "/Library/LaunchDaemons/us.zoom.ZoomDaemon.plist"

# Clear system caches for Zoom
echo "Clearing system caches for Zoom..."
sudo rm -rf /private/var/db/receipts/*zoom* 2>/dev/null
sudo rm -rf /private/var/folders/*/*/*zoom* 2>/dev/null || echo "No cached Zoom files found."

# Verify removal of files
echo "Verifying Zoom removal..."
find ~/Library /Library -iname "*zoom*" 2>/dev/null
if [ $? -eq 0 ]; then
  echo "Some Zoom-related files may still exist. Please check manually if needed."
else
  echo "All Zoom-related files successfully removed!"
fi

# Restart the system (optional)
echo "Zoom uninstallation completed! You may want to reboot your system to refresh all processes."